#ifndef _YASPOT_SETTINGS_H_FOO_
#define _YASPOT_SETTINGS_H_FOO_

#include <glib.h>

#include "userdata.h"

gchar* yaspot_settings_username();
gchar* yaspot_settings_password();
int yaspot_settings_set_username(const gchar *username);
int yaspot_settings_set_password(const gchar *password);

int yaspot_settings_save_credentials(int *save_credentials);
int yaspot_settings_set_save_credentials(int save_credentials);

int yaspot_settings_high_bitrate(int *high_bitrate);
int yaspot_settings_set_high_bitrate(int high_bitrate);

/* settings that are restored when invoking yaspot_settings_restore */

int yaspot_settings_autoshow_queue(gint autoshow_queue);
int yaspot_settings_get_autoshow_queue(gint *autoshow_queue);

/* try to restore aforementioned settings to userdata */
void yaspot_settings_restore(userdata_t *u);

#endif

// vim: expandtab shiftwidth=4

